#ifndef LOG_H_
#define LOG_H_

#include <QString>

namespace kdk
{
namespace kabase
{

class Log
{
public:
    enum LogLevel {
        Debug = 0, /* 调试 */
        Info,      /* 信息 */
        Warning,   /* 警告 */
        Error,     /* 错误 */
        Fatal      /* 致命 */
    };

    Log();
    Log(LogLevel logLevel);
    ~Log();

    /*
     * 功能 : 操作符重载 , 基于 kysdk
     * 参数 : int 变量
     * 返回 : *this
     */
    const Log &operator<<(int value) const;
    const Log &operator<<(float value) const;
    const Log &operator<<(double value) const;
    const Log &operator<<(const char *str) const;
    const Log &operator<<(char *str) const;
    const Log &operator<<(std::string str) const;
    const Log &operator<<(QString str) const;
    const Log &operator<<(bool value) const;
    const Log &operator<<(void *ptr) const;

    /**
     * @brief 用于 Qt 注册日志函数 , 不应该单独调用
     *
     * @param type 日志类型
     * @param context 调用文件信息
     * @param msg 需要打印的日志
     *
     * @return 无
     */
    static void logOutput(QtMsgType type, const QMessageLogContext &context, const QString &msg);

private:
    LogLevel m_logLevel;
};

extern Log debug;
extern Log info;
extern Log warning;
extern Log error;
extern Log fatal;

} /* namespace kabase */
} /* namespace kdk */

#endif
